% Solution for spring flow recession following 'cessation of recharge'
% 
% If used, please acknowldege the source of this code & also cite these two
% papers:
% 1. Cuthbert et al. 2017 "Modelling the role of groundwater hydro-refugia
% in East African hominin evolution and dispersal", Nature Communications
% 2. Cuthbert & Ashley 2014 "A Spring Forward for Hominin Evolution in East
% Africa" PlosOne e107358
%
% Feel free to contact Dr Mark Cuthbert at cuthbertm2@cardiff.ac.uk
%
% Note there was a typo (missing minus sign) in  the definition of zn pn p4
% of Cuthbert & Ashley (2014): Equation 2 should have read that zn is nth
% root of tan(z) = -2z/Hi - this is corrected in Cuthbert et al. (2017)
%
% This script was used to generate Supplementray Figure 3 in Cuthbert et al
% (2017) and needs the following spreadsheet associated with this Matlab 
% script as input "AverageSpringSensitivity.xlsx"


clear all; close all; clc;

%get spring params from excel for sensitivity analysis to individual params
input = 'AverageSpringSensitivity.xlsx'
output = 'AverageSpringSensitivity.xlsx'
k = xlsread(input, 'input', 'b3:b19');
alpha = xlsread(input, 'input', 'c3:c19');
Bx = xlsread(input, 'input', 'd3:d19');
R = xlsread(input, 'input', 'e3:e19');
A = xlsread(input, 'input', 'f3:f19');
ne = xlsread(input, 'input', 'g3:g19');
D0 = xlsread(input, 'input', 'h3:h19');
eta = xlsread(input, 'input', 'i3:i19');

%times in years (check 365 is in the expression for tplus)
timestep = 1;
startime = timestep;   
endtime = 100;    
qthresh = 1000;   %define threshold for defining response time m3/year
numsprings =17;   %number of springs to run calculations for

%setup other variables
t = (startime:timestep:endtime);
numsteps = numel(t);
t_thresh = zeros(1,numsprings);
W = 0.5-1e-10;

for i = 1:numsprings;  %loop through spring sites
  ki = k(i); %in m/d
  Bxi = Bx(i);   %in m
  alphai = alpha(i);
  k0ONne = k(i)/ne(i);
  Ri = R(i);
  Ai = A(i);
  eta0 = D0(i)*eta(i);
  tind = 0;
    for j=1:numsteps    %time loop
        %if Bx(i)> 0;
            qt = 0;  %initialise total flux variable
            for n=1:10000;   %summation loop
                tplus=k0ONne*eta0*cos(alphai)*t(j)*365/Bxi^2;
                if alpha(i) > 0;
                    z0 = [n*pi-W*pi n*pi];   %range in which to search for root - won't work if first term is exactly a multiple of pi/2
                    Hi = Bxi*tan(alphai)/eta0;    %in m
                    fun = @(z)(tan(z)+2*z/Hi);
                    zn = fzero(fun,z0);  %find nth root of fun
                    else
                    zn = (2*n-1)*pi/2;  %solution for no slope 
                    Hi = 0;
                end 
                qn = 2*zn^2*(1-2*cos(zn)*exp(Hi/2))*exp(-(zn^2+Hi^2/4)*tplus)/((zn^2+Hi^2/4+Hi/2)*(zn^2+Hi^2/4));
                qt = qt + qn;
              if abs(qt) < 0.00001;
                   break
               end
               if abs(qn/qt) < 0.00001;
                   break
              end
            end     %end summation loop
        
        tind = tind + 1;
        qresults(tind,i) = qt;
        qabs(tind,i) = qt*Ri/1000*Ai ;
        %get time when qthresh reached
            if qt*Ri/1000*Ai > qthresh;
                t_thresh(1,i)=t(j);   
            end
        
    end        %end time loop
   i
end

plot(qabs)
title('East African Spring Recession Sensitivity')
xlabel('Time (y)')
ylabel('Spring flow, m3/y')
legend('Baseline','k min', 'k max','alpha min','alpha max','B min','B max',...
'R min','R max','A min','A max','Sy min','Sy max','D min','D max','eta min',...
'eta max');
print('AverageSpringSensitivity','-dpng')

cdfplot(t_thresh);
%set(gca,'XScale','log');
set(gca,'fontsize',18)
set(gca,'Ylim',[0,1]);
print('AverageSpringSensitivity_CDF','-dpng')

header = (1:numsprings);
xlswrite(output, {'Time (y)'},'results','A1');
xlswrite(output, header,'results','B1');
xlswrite(output, t','results','A2');
xlswrite(output, qabs,'results','B2');
xlswrite(output, 't_to_1000_m3/d','results','T1');
xlswrite(output, t_thresh','results','T2');

